@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.2.0>;
+unit module TAP:ver<0.2.1>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -108,7 +108,7 @@ class Result {
         @!failed || @!errors || (!$ignore-exit && self.exit-failed);
     }
     method exit-failed() {
-        $!exit-status.defined && $!exit-status.status;
+        $!exit-status.defined && ($!exit-status.exitcode || $!exit-status.signal);
     }
 }
 
